@@ -64,11 +64,9 @@ enum Fl_Color {	// standard colors
   FL_COLOR_CUBE		= 56
 };
 #else // GIAC_HAS_STO_38
-#ifndef LP64
+//#ifndef LP64
 typedef ptrdiff_t Int;
-#else
-typedef signed long Int;
-#endif
+//#else typedef signed long Int; #endif
 #include "Colors.h"
 //#include "../../src/Colors.h"
 enum Fl_Color {
@@ -330,6 +328,7 @@ namespace giac {
   extern const unary_function_ptr * const  at_ordonnee;
 
   gen _cote(const gen & args,GIAC_CONTEXT);
+  extern const unary_function_ptr * const  at_cote;
   extern const unary_function_ptr * const  at_coordonnees;
   gen _coordonnees(const gen & args,GIAC_CONTEXT);
   gen _coordonnees_polaires(const gen & args,GIAC_CONTEXT);
